"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTextExistence = exports.getInnerText = exports.handleWarningsAndErrors = exports.sanitizeHTMLTags = exports.compileLinkTag = exports.defineOptions = void 0;
var env_1 = require("./env");
function defineOptions(options) {
    var urlRegEx = options.urlRegEx ? options.urlRegEx : env_1.defaultUrlRegExp;
    var target = options.target ? options.target : env_1.defaultTarget;
    var disableWarnings = options.disableWarnings ? options.disableWarnings : env_1.defaultWarnings;
    return { urlRegEx: urlRegEx, target: target, disableWarnings: disableWarnings };
}
exports.defineOptions = defineOptions;
;
function compileLinkTag(link, target) {
    return "<a href=\"".concat(link, "\" target=\"").concat(target, "\">").concat(link, "</a>");
}
exports.compileLinkTag = compileLinkTag;
function sanitizeHTMLTags(text) {
    return text.replace(/</g, '&lt;');
}
exports.sanitizeHTMLTags = sanitizeHTMLTags;
function handleWarningsAndErrors(vnode, options, textExists) {
    // ignoring disableWarnings feature, due to deprecated mode v-dolinks="'text'"
    if (textExists.arg) {
        console.error("v-dolinks [DEPRECATED use case: v-dolinks=\"'your text'\"] (in <".concat(vnode.tag, "> tag):"), 'move text from v-dolinks arg to inner tag text:', '<p v-dolinks>"{{ yourTextAsValue }}"</p>');
    }
    if (options.disableWarnings)
        return;
    if (!textExists.inner) {
        console.warn("v-dolinks (in <".concat(vnode.tag, "> tag):"), 'element uses dolinks directive but has no text;');
    }
}
exports.handleWarningsAndErrors = handleWarningsAndErrors;
function getInnerText(textExists, inner, arg) {
    if (textExists.arg)
        return arg;
    return inner;
}
exports.getInnerText = getInnerText;
function getTextExistence(inner, arg) {
    var isInnerText = (inner.length > 0);
    var isArgText = (arg.length > 0);
    return {
        'inner': isInnerText,
        'arg': isArgText,
    };
}
exports.getTextExistence = getTextExistence;
